@@ -1,23 +1,3 @@
-# Copyright (c) 2019 Sean Vig
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the \"Software\"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
 """
 The objects in the command graph and command resolution on the objects
 """
@@ -44,6 +24,15 @@ if TYPE_CHECKING:
     ItemT = tuple[bool, list[str | int]] | None
 
 
+def allow_when_locked(func: Callable) -> Callable:
+    """
+    Decorator to expose methods which can be run when the
+    session is locked.
+    """
+    setattr(func, "_allow_when_locked", True)
+    return func
+
+
 def expose_command(name: Callable | str | list[str] | None = None) -> Callable:
     """
     Decorator to expose methods to the command interface.
@@ -316,29 +305,24 @@ class CommandObject(metaclass=abc.ABCMeta):
         return str(signature)
 
     @expose_command()
-    def eval(self, code: str) -> tuple[bool, str | None]:
+    def eval(self, code: str) -> str | None:
         """Evaluates code in the same context as this function
 
-        Return value is tuple `(success, result)`, success being a boolean and
-        result being a string representing the return value of eval, or None if
+        Return a string representing the return value of eval, or None if
         exec was used instead.
         """
+        globals_ = vars(sys.modules[self.__module__])
         try:
-            globals_ = vars(sys.modules[self.__module__])
-            try:
-                return True, str(eval(code, globals_, locals()))
-            except SyntaxError:
-                exec(code, globals_, locals())
-                return True, None
-        except Exception:
-            error = traceback.format_exc().strip().split("\n")[-1]
-            return False, error
+            return str(eval(code, globals_, locals()))
+        except SyntaxError:
+            exec(code, globals_, locals())
+            return None
 
     @expose_command()
     def function(self, function, *args, **kwargs) -> asyncio.Task | None:
         """Call a function with current object as argument"""
         try:
-            if asyncio.iscoroutinefunction(function):
+            if inspect.iscoroutinefunction(function):
                 return create_task(function(self, *args, **kwargs))
             else:
                 return function(self, *args, **kwargs)
