@@ -13,7 +13,7 @@ from libqtile.log_utils import logger
 
 if TYPE_CHECKING:
     from collections.abc import Callable, Iterable
-    from typing import Any
+    from typing import Any, Literal
 
     from libqtile.backend import base
     from libqtile.bar import BarType
@@ -514,7 +514,6 @@ class Screen(CommandObject):
     def finalize_gap(self, position: str) -> None:
         gap = getattr(self, position, None)
         if gap is not None:
-            setattr(self, position, None)
             gap.finalize()
 
     def finalize_gaps(self) -> None:
@@ -1142,6 +1141,32 @@ class Rule:
         return f"<Rule match={self.matchlist!r} actions=({actions})>"
 
 
+class IdleInhibitor:
+    """
+    Note: Wayland Only
+
+    Create rules for when the compositor should not go into an idle state.
+
+    IdleInhibitor take two arguments:
+      -  match: a ``Match`` object to define which windows the rule should apply to. If unset, it will apply to all windows.
+                Note: qtile evaluates whether a rule mtahces a window once, when the window is first created.
+      -  when: one of the following strings:
+        - "focus" (default): Inhibitor is active when the matching window is the currently focused window
+        - "fullscreen": Inhibitor is active when the matching window is fullscreen
+        - "visible": Inhibitor is active when the matching window is visible on any screen
+                     (still applies if window is completely covered by a floating window)
+        - "open": Inhibitor is active when the matching window is open (even if hidden)
+    """
+
+    def __init__(
+        self,
+        match: _Match | None = None,
+        when: Literal["focus" | "fullscreen" | "visible" | "open"] = "open",
+    ):
+        self.match = match
+        self.when = when
+
+
 class DropDown(configurable.Configurable):
     """
     Configure a specified command and its associated window for the :class:`ScratchPad`.
