@@ -1,31 +1,3 @@
-# Copyright (c) 2012-2014 Tycho Andersen
-# Copyright (c) 2013 xarvh
-# Copyright (c) 2013 roger
-# Copyright (c) 2013 Tao Sauvage
-# Copyright (c) 2014 ramnes
-# Copyright (c) 2014 Sean Vig
-# Copyright (c) 2014 dequis
-# Copyright (c) 2015 Dario Giovannetti
-# Copyright (c) 2015 Alexander Lozovskoy
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
@@ -170,6 +142,9 @@ class _Group(CommandObject):
                         # Screen has lost focus so we reset record of focused window so
                         # focus will warp when screen is focused again
                         self.last_focused = None
+        elif self.screen and not self.windows and self.screen == self.qtile.current_screen:
+            # Clear active window when switching to an empty group on the current screen
+            self.qtile.core.clear_focus()
 
     def set_screen(self, screen, warp=True):
         """Set this group's screen to screen"""
@@ -273,6 +248,18 @@ class _Group(CommandObject):
 
     def remove(self, win, force=False):
         hook.fire("group_window_remove", self, win)
+
+        if self.qtile.config.focus_previous_on_window_remove:
+            index = self.focus_history.index(win)
+            try:
+                previous_win = self.focus_history[index - 1]
+            except IndexError:
+                previous_win = None
+            if previous_win not in self.windows:
+                previous_win = None
+        else:
+            previous_win = None
+
         self.windows.remove(win)
         hadfocus = self._remove_from_focus_history(win)
         win.group = None
@@ -281,7 +268,8 @@ class _Group(CommandObject):
             nextfocus = self.floating_layout.remove(win)
 
             nextfocus = (
-                nextfocus
+                previous_win
+                or nextfocus
                 or self.current_window
                 or self.layout.focus_first()
                 or self.floating_layout.focus_first(group=self)
@@ -295,7 +283,8 @@ class _Group(CommandObject):
                     i.remove(win)
 
             nextfocus = (
-                nextfocus
+                previous_win
+                or nextfocus
                 or self.floating_layout.focus_first(group=self)
                 or self.current_window
                 or self.layout.focus_first()
@@ -404,6 +393,8 @@ class _Group(CommandObject):
         else:
             screen.set_group(self)
 
+        self.qtile.core.check_screen_fullscreen_background(screen)
+
     def _get_group(self, direction, skip_empty=False, skip_managed=False):
         """Find a group walking the groups list in the specified direction
 
